==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/messaging/v1/SubscriptionStatusPhysicalSubscriptionBuilder.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SubscriptionStatusPhysicalSubscriptionBuilder extends SubscriptionStatusPhysicalSubscriptionFluentImpl<SubscriptionStatusPhysicalSubscriptionBuilder> implements VisitableBuilder<SubscriptionStatusPhysicalSubscription,SubscriptionStatusPhysicalSubscriptionBuilder> {

    SubscriptionStatusPhysicalSubscriptionFluent<?> fluent;
    Boolean validationEnabled;

    public SubscriptionStatusPhysicalSubscriptionBuilder() { 
        this(true);
    }


    public SubscriptionStatusPhysicalSubscriptionBuilder(Boolean validationEnabled) { 
        this(new SubscriptionStatusPhysicalSubscription(), validationEnabled);
    }


    public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscriptionFluent<?> fluent) { 
        this(fluent, true);
    }


    public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscriptionFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new SubscriptionStatusPhysicalSubscription(), validationEnabled);
    }


    public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscriptionFluent<?> fluent,SubscriptionStatusPhysicalSubscription instance) { 
        this(fluent, instance, true);
    }


    public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscriptionFluent<?> fluent,SubscriptionStatusPhysicalSubscription instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withDeadLetterSinkUri(instance.getDeadLetterSinkUri()); 
        fluent.withReplyUri(instance.getReplyUri()); 
        fluent.withSubscriberUri(instance.getSubscriberUri()); 
        this.validationEnabled = validationEnabled; 
    }


    public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscription instance) { 
        this(instance,true);
    }


    public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscription instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withDeadLetterSinkUri(instance.getDeadLetterSinkUri()); 
        this.withReplyUri(instance.getReplyUri()); 
        this.withSubscriberUri(instance.getSubscriberUri()); 
        this.validationEnabled = validationEnabled; 
    }


    public SubscriptionStatusPhysicalSubscription build() {
        SubscriptionStatusPhysicalSubscription buildable = new SubscriptionStatusPhysicalSubscription(fluent.getDeadLetterSinkUri(),fluent.getReplyUri(),fluent.getSubscriberUri());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SubscriptionStatusPhysicalSubscriptionBuilder that = (SubscriptionStatusPhysicalSubscriptionBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/messaging/v1/SubscriptionStatusPhysicalSubscriptionBuilder.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SubscriptionStatusPhysicalSubscriptionBuilder extends SubscriptionStatusPhysicalSubscriptionFluentImpl<SubscriptionStatusPhysicalSubscriptionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<SubscriptionStatusPhysicalSubscription,SubscriptionStatusPhysicalSubscriptionBuilder> {

    SubscriptionStatusPhysicalSubscriptionFluent<?> fluent;
    Boolean validationEnabled;

    public SubscriptionStatusPhysicalSubscriptionBuilder() {
        this(true);
    }

    public SubscriptionStatusPhysicalSubscriptionBuilder(Boolean validationEnabled) {
        this(new SubscriptionStatusPhysicalSubscription(), validationEnabled);
    }

    public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscriptionFluent<?> fluent) {
        this(fluent, true);
    }

    public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscriptionFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new SubscriptionStatusPhysicalSubscription(), validationEnabled);
    }

    public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscriptionFluent<?> fluent,SubscriptionStatusPhysicalSubscription instance) {
        this(fluent, instance, true);
    }

    public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscriptionFluent<?> fluent,SubscriptionStatusPhysicalSubscription instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withDeadLetterSinkUri(instance.getDeadLetterSinkUri()); 
        fluent.withReplyUri(instance.getReplyUri()); 
        fluent.withSubscriberUri(instance.getSubscriberUri()); 
        this.validationEnabled = validationEnabled; 
    }

    public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscription instance) {
        this(instance,true);
    }

    public SubscriptionStatusPhysicalSubscriptionBuilder(SubscriptionStatusPhysicalSubscription instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withDeadLetterSinkUri(instance.getDeadLetterSinkUri()); 
        this.withReplyUri(instance.getReplyUri()); 
        this.withSubscriberUri(instance.getSubscriberUri()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.messaging.v1.EditableSubscriptionStatusPhysicalSubscription build() {
        EditableSubscriptionStatusPhysicalSubscription buildable = new EditableSubscriptionStatusPhysicalSubscription(fluent.getDeadLetterSinkUri(),fluent.getReplyUri(),fluent.getSubscriberUri());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SubscriptionStatusPhysicalSubscriptionBuilder that = (SubscriptionStatusPhysicalSubscriptionBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
